@@ -20,8 +20,7 @@ from ampform.sympy import (
     create_expression,
     implement_doit_method,
 )
-
-from .math import ComplexSqrt
+from ampform.sympy.math import ComplexSqrt
 
 if sys.version_info >= (3, 8):
     from typing import Protocol
@@ -29,7 +28,7 @@ else:
     from typing_extensions import Protocol
 
 
-@implement_doit_method()
+@implement_doit_method
 class BlattWeisskopfSquared(UnevaluatedExpression):
     r"""Blatt-Weisskopf function :math:`B_L^2(z)`, up to :math:`L \leq 8`.
 
@@ -149,7 +148,7 @@ class BlattWeisskopfSquared(UnevaluatedExpression):
 
 
 class PhaseSpaceFactorProtocol(Protocol):
-    """Protocol that is used by `.CoupledWidth`.
+    """Protocol that is used by `.EnergyDependentWidth`.
 
     Use this `~typing.Protocol` when defining other implementations of a phase
     space factor. Compare for instance `.PhaseSpaceFactor` and
@@ -163,7 +162,7 @@ class PhaseSpaceFactorProtocol(Protocol):
         ...
 
 
-@implement_doit_method()
+@implement_doit_method
 class PhaseSpaceFactor(UnevaluatedExpression):
     """Standard phase-space factor, using :func:`BreakupMomentumSquared`.
 
@@ -191,7 +190,7 @@ class PhaseSpaceFactor(UnevaluatedExpression):
         return fR"{name}\left({s}\right)"
 
 
-@implement_doit_method()
+@implement_doit_method
 class PhaseSpaceFactorAbs(UnevaluatedExpression):
     r"""Phase space factor square root over the absolute value.
 
@@ -226,7 +225,7 @@ class PhaseSpaceFactorAbs(UnevaluatedExpression):
         return fR"{name}\left({s}\right)"
 
 
-@implement_doit_method()
+@implement_doit_method
 class PhaseSpaceFactorAnalytic(UnevaluatedExpression):
     """Analytic continuation for the :func:`PhaseSpaceFactor`.
 
@@ -262,7 +261,7 @@ class PhaseSpaceFactorAnalytic(UnevaluatedExpression):
         return fR"{name}\left({s}\right)"
 
 
-@implement_doit_method()
+@implement_doit_method
 class PhaseSpaceFactorComplex(UnevaluatedExpression):
     """Phase-space factor with `.ComplexSqrt`.
 
@@ -318,8 +317,8 @@ def _phase_space_factor_denominator(s: sp.Symbol) -> sp.Expr:
     return 8 * sp.pi * sp.sqrt(s)
 
 
-@implement_doit_method()
-class CoupledWidth(UnevaluatedExpression):
+@implement_doit_method
+class EnergyDependentWidth(UnevaluatedExpression):
     r"""Mass-dependent width, coupled to the pole position of the resonance.
 
     See :pdg-review:`2020; Resonances; p.6` and
@@ -351,7 +350,7 @@ class CoupledWidth(UnevaluatedExpression):
         phsp_factor: Optional[PhaseSpaceFactorProtocol] = None,
         name: Optional[str] = None,
         evaluate: bool = False,
-    ) -> "CoupledWidth":
+    ) -> "EnergyDependentWidth":
         args = sp.sympify(
             (s, mass0, gamma0, m_a, m_b, angular_momentum, meson_radius)
         )
@@ -396,7 +395,7 @@ class CoupledWidth(UnevaluatedExpression):
         return fR"{name}\left({s}\right)"
 
 
-@implement_doit_method()
+@implement_doit_method
 class BreakupMomentumSquared(UnevaluatedExpression):
     r"""Squared value of the two-body break-up momentum.
 
@@ -467,7 +466,7 @@ def relativistic_breit_wigner_with_ff(  # pylint: disable=too-many-arguments
         angular_momentum, z=q_squared * meson_radius ** 2
     )
     form_factor = sp.sqrt(ff_squared)
-    mass_dependent_width = CoupledWidth(
+    mass_dependent_width = EnergyDependentWidth(
         s, mass0, gamma0, m_a, m_b, angular_momentum, meson_radius, phsp_factor
     )
     return (mass0 * gamma0 * form_factor) / (
