@@ -19,7 +19,6 @@ import logging
 import sys
 from collections import abc
 from typing import (
-    TYPE_CHECKING,
     Any,
     Callable,
     Dict,
@@ -32,21 +31,19 @@ from typing import (
     Union,
 )
 
+import sympy as sp
 from ipywidgets.widgets import FloatSlider, IntSlider
 from sympy.printing.latex import translate
 
-import sympy as sp
-
 try:
     from IPython.lib.pretty import PrettyPrinter
 except ImportError:
     PrettyPrinter = Any
 
-if TYPE_CHECKING:
-    if sys.version_info >= (3, 10):
-        from typing import TypeGuard  # pylint: disable=no-name-in-module
-    else:
-        from typing_extensions import TypeGuard
+if sys.version_info >= (3, 10):
+    from typing import TypeGuard  # pylint: disable=no-name-in-module
+else:
+    from typing_extensions import TypeGuard
 
 
 Slider = Union[FloatSlider, IntSlider]
@@ -192,7 +189,8 @@ class SliderKwargs(abc.Mapping):
         for slider_name, range_def in range_definitions.items():
             if not isinstance(range_def, tuple):
                 raise TypeError(
-                    f'Range definition for slider "{slider_name}" is not a tuple'
+                    f'Range definition for slider "{slider_name}" is not a'
+                    " tuple"
                 )
             slider = self[slider_name]
             if _is_min_max(range_def):
@@ -221,9 +219,7 @@ class SliderKwargs(abc.Mapping):
                 slider.step = step_size
 
 
-def _is_min_max(
-    range_def: RangeDefinition,
-) -> "TypeGuard[Tuple[float, float]]":
+def _is_min_max(range_def: RangeDefinition) -> TypeGuard[Tuple[float, float]]:
     if len(range_def) == 2:
         return True
     return False
@@ -231,7 +227,7 @@ def _is_min_max(
 
 def _is_min_max_step(
     range_def: RangeDefinition,
-) -> "TypeGuard[Tuple[float, float, Union[float, int]]]":
+) -> TypeGuard[Tuple[float, float, Union[float, int]]]:
     if len(range_def) == 3:
         return True
     return False
@@ -265,8 +261,6 @@ def prepare_sliders(
     # cspell:ignore lambdifygenerated
     """Lambdify a `sympy` expression and create sliders for its arguments.
 
-    >>> import sympy as sp
-    >>> from symplot import prepare_sliders
     >>> n = sp.Symbol("n", integer=True)
     >>> x = sp.Symbol("x")
     >>> expression, sliders = prepare_sliders(x ** n, plot_symbol=x)
@@ -298,8 +292,6 @@ def create_slider(symbol: sp.Symbol) -> Slider:
     The description for the slider is rendered as LaTeX from the
     `~sympy.core.symbol.Symbol` name.
 
-    >>> import sympy as sp
-    >>> from symplot import create_slider
     >>> create_slider(sp.Symbol("a"))
     FloatSlider(value=0.0, description='\\(a\\)')
     >>> create_slider(sp.Symbol("n0", integer=True))
@@ -342,7 +334,7 @@ def __safe_wrap_symbols(
 
 def partial_doit(
     expression: sp.Expr,
-    doit_classes: Union[Type[sp.Basic], Tuple[Type[sp.Basic]]],
+    doit_classes: Union[Type[sp.Basic], Tuple[Type[sp.Basic], ...]],
 ) -> sp.Expr:
     """Perform :meth:`~sympy.core.basic.Basic.doit` up to a certain level.
 
